@@ -4,7 +4,6 @@ set -ex
 
 DAEMON_TIMEOUT=60
 CRM_TIMEOUT=5
-NODE=node1
 
 # https://bugs.launchpad.net/bugs/1828228
 ulimit -H -l unlimited 2>/dev/null || {
@@ -20,6 +19,11 @@ service corosync start
 service pacemaker start
 sleep $DAEMON_TIMEOUT
 
+POS="$(corosync-cmapctl -q -g nodelist.local_node_pos)"
+NODE="$(corosync-cmapctl -q -g nodelist.node.$POS.name)"
+IP="$(corosync-cmapctl -q -g nodelist.node.$POS.ring0_addr)"
+echo "$IP $NODE" >> /etc/hosts
+
 #
 # online
 #
@@ -60,7 +64,6 @@ crm node utilization $NODE set memory 2048
 crm node utilization $NODE show memory | grep 2048
 crm node server
 crm node show
-crm node status
 
 : INFO all tests OK
 exit 0
